clc;close;clear;
%--------------------------------------------------------------------------
% General system parameters and mesh parameters
%--------------------------------------------------------------------------
% Enter number of desired elements in both the x- and y-directions
n_ele_x = 6; % number of elements in the x-direction
n_ele_y = 6; % number of elements in the y-direction
% Enter the width and height of the domain being studied here
Lx = .1; %[m], domain width
Ly = .1; %[m], domain height
% Enter the thermal conductivity of the material for the x- and
% y-directions
kx = 25; %[W/m-K], thermal conductivity of material in x-dir
ky = 25; %[W/m-K], thermal conductivity of material in y-dir
% Enter the material's density
rho = 2170; %[kg/m^3], density of the material
% Enter the material's specific heat
cp = 980; %[W/kg-K], specific heat of the material
% Compute some new paramerters based on system inputs for later
% computations
dof = (n_ele_x+1)*(n_ele_y+1);
dx = Lx/n_ele_x; %[m], element width
dy = Ly/n_ele_y; %[m], element height
%--------------------------------------------------------------------------
% Boundary conditions, they are all convective heat transfer, the right
% side has the chill plate mounted and all others will generally be modeled
% as natural convection to the atmosphere
%--------------------------------------------------------------------------
h1 = 5;   % W/m^2-K, heat transfer coefficient for the bottom edge
h2 = 5; % W/m^2-K, heat transfer coefficient for the right edge
h3 = 5;   % W/m^2-K, heat transfer coefficient for the top edge
h4 = 5;   % W/m^2-K, heat transfer coefficient for the left edge
room_temp = 25;
Te1 = 273.1+room_temp;  % Kelvin, temperature of environment at bottom edge
Te2 = 273.1+room_temp;          % Kelvin, temperature of environment at right edge
Te3 = 273.1+room_temp;  % Kelvin, temperature of environment at top edge
Te4 = 273.1+room_temp;  % Kelvin, temperature of environment at left edge
%--------------------------------------------------------------------------
% Compute the individual elemental conductivity matrix for the core
% elements
%--------------------------------------------------------------------------
%[Kcond_core] = coreCond(kx,ky,dx,dy);
%Kcn = Kcond*dx/(kx*dx*dy);
%--------------------------------------------------------------------------
% Create nodal coordinates
%--------------------------------------------------------------------------
[n_coords] = elementCoords(n_ele_x,n_ele_y,dx,dy);
% Can use next line to plot the coordinate points for testing
%plot(n_coords(:,1),n_coords(:,2),'*k')
%--------------------------------------------------------------------------
% Create element global node numbering
%--------------------------------------------------------------------------
[elem_nodes] = findElemNodes(n_ele_x,n_ele_y);
%-------------------------------------------------------------------------- 
% Find elements in certain locations (ie bott, top, core, corners, etc)
%--------------------------------------------------------------------------
[core_elems,corner_elems,bott_elems,top_elems,right_elems,left_elems] = findElems(n_ele_x,n_ele_y);  
%--------------------------------------------------------------------------
% Create global sized matrices for each element
% Core elements
h_core = [0 0 0 0];
Tamb_core = [0 0 0 0];
Kcores1 = zeros(dof,dof);
Ccores1 = zeros(dof,dof);
Rcores1 = zeros(dof,1);
[Ctot_core,Ktot_core,Rtot_core] = SymbolicEqns_LinearShape(dx,dy,h_core,Tamb_core,rho,cp);
[Kcores1,Ccores1,Rcores1] = assemble(Ktot_core,Ctot_core,Rtot_core,core_elems,dof,elem_nodes,Kcores1,Ccores1,Rcores1);
% left elements
h_left = [0 0 0 h4];
Tamb_left = [0 0 0 Te4];
[Ctot_lefts,Ktot_lefts,Rtot_lefts] = SymbolicEqns_LinearShape(dx,dy,h_left,Tamb_left,rho,cp);
Klefts1 = zeros(dof,dof);
Clefts1 = zeros(dof,dof);
Rlefts1 = zeros(dof,1);
[Klefts1,Clefts1,Rlefts1] = assemble(Ktot_lefts,Ctot_lefts,Rtot_lefts,left_elems,dof,elem_nodes,Klefts1,Clefts1,Rlefts1);
% Right elements
h_right = [0 h2 0 0];
Tamb_right = [0 Te2 0 0];
[Ctot_rights,Ktot_rights,Rtot_rights] = SymbolicEqns_LinearShape(dx,dy,h_right,Tamb_right,rho,cp);
Krights1 = zeros(dof,dof);
Crights1 = zeros(dof,dof);
Rrights1 = zeros(dof,1);
[Krights1,Crights1,Rrights1] = assemble(Ktot_rights,Ctot_rights,Rtot_rights,right_elems,dof,elem_nodes,Krights1,Crights1,Rrights1);
% Top elements
h_top = [0 0 h3 0];
Tamb_top = [0 0 Te3 0];
[Ctot_tops,Ktot_tops,Rtot_tops] = SymbolicEqns_LinearShape(dx,dy,h_top,Tamb_top,rho,cp);
Ktops1 = zeros(dof,dof);
Ctops1 = zeros(dof,dof);
Rtops1 = zeros(dof,1);
[Ktops1,Ctops1,Rtops1] = assemble(Ktot_tops,Ctot_tops,Rtot_tops,top_elems,dof,elem_nodes,Ktops1,Ctops1,Rtops1);
% Bottom elements
h_bott = [h1 0 0 0];
Tamb_bott = [Te1 0 0 0];
[Ctot_botts,Ktot_botts,Rtot_botts] = SymbolicEqns_LinearShape(dx,dy,h_bott,Tamb_bott,rho,cp);
Kbotts1 = zeros(dof,dof);
Cbotts1 = zeros(dof,dof);
Rbotts1 = zeros(dof,1);
[Kbotts1,Cbotts1,Rbotts1] = assemble(Ktot_botts,Ctot_botts,Rtot_botts,bott_elems,dof,elem_nodes,Kbotts1,Cbotts1,Rbotts1);
% Bottom left corner
h_bl = [h1 0 0 h4];
Tamb_bl = [Te1 0 0 Te4];
[Ctot_bl,Ktot_bl,Rtot_bl] = SymbolicEqns_LinearShape(dx,dy,h_bl,Tamb_bl,rho,cp);
Kbl1 = zeros(dof,dof);
Cbl1 = zeros(dof,dof);
Rbl1 = zeros(dof,1);
[Kbl1,Cbl1,Rbl1] = assemble(Ktot_bl,Ctot_bl,Rtot_bl,corner_elems(1),dof,elem_nodes,Kbl1,Cbl1,Rbl1);
% Bottom right corner
h_br = [h1 h2 0 0];
Tamb_br = [Te1 Te2 0 0];
[Ctot_br,Ktot_br,Rtot_br] = SymbolicEqns_LinearShape(dx,dy,h_br,Tamb_br,rho,cp);
Kbr1 = zeros(dof,dof);
Cbr1 = zeros(dof,dof);
Rbr1 = zeros(dof,1);
[Kbr1,Cbr1,Rbr1] = assemble(Ktot_br,Ctot_br,Rtot_br,corner_elems(2),dof,elem_nodes,Kbr1,Cbr1,Rbr1);
% Top right corner
h_tr = [0 h2 h3 0];
Tamb_tr = [0 Te2 Te3 0];
[Ctot_tr,Ktot_tr,Rtot_tr] = SymbolicEqns_LinearShape(dx,dy,h_tr,Tamb_tr,rho,cp);
Ktr1 = zeros(dof,dof);
Ctr1 = zeros(dof,dof);
Rtr1 = zeros(dof,1);
[Ktr1,Ctr1,Rtr1] = assemble(Ktot_tr,Ctot_tr,Rtot_tr,corner_elems(3),dof,elem_nodes,Ktr1,Ctr1,Rtr1);
% Top left corner
h_tl = [0 0 h3 h4];
Tamb_tl = [0 0 Te3 Te4];
[Ctot_tl,Ktot_tl,Rtot_tl] = SymbolicEqns_LinearShape(dx,dy,h_tl,Tamb_tl,rho,cp);
Ktl1 = zeros(dof,dof);
Ctl1 = zeros(dof,dof);
Rtl1 = zeros(dof,1);
[Ktl1,Ctl1,Rtl1] = assemble(Ktot_tl,Ctot_tl,Rtot_tl,corner_elems(4),dof,elem_nodes,Ktl1,Ctl1,Rtl1);

% Create global matrices
Cg = Ccores1+Ctops1+Cbotts1+Clefts1+Crights1+Cbl1+Cbr1+Ctr1+Ctl1;
Kg = Kcores1+Ktops1+Kbotts1+Klefts1+Krights1+Kbl1+Kbr1+Ktr1+Ktl1;
Rg = Rcores1+Rtops1+Rbotts1+Rlefts1+Rrights1+Rbl1+Rbr1+Rtr1+Rtl1;

save(['GlobalSys_Settling_' num2str(n_ele_x) 'by' num2str(n_ele_y) '_030713.mat'],'Cg','Kg','Rg','n_coords')
